@@ -455,7 +455,7 @@ class Application(
         .. versionadded:: 20.0
         """
         # Unfortunately this needs to be here due to cyclical imports
-        from telegram.ext import (  # noqa: PLC0415  # pylint: disable=import-outside-toplevel
+        from telegram.ext import (  # pylint: disable=import-outside-toplevel  # noqa: PLC0415
             ApplicationBuilder,
         )
 
@@ -1025,10 +1025,15 @@ class Application(
         bootstrap_retries: int,
         close_loop: bool = True,
     ) -> None:
-        # Calling get_event_loop() should still be okay even in py3.10+ as long as there is a
-        # running event loop, or we are in the main thread, which are the intended use cases.
-        # See the docs of get_event_loop() and get_running_loop() for more info
-        loop = asyncio.get_event_loop()
+        # Try to get the running event loop first, and if there isn't one, create a new one.
+        # This handles the Python 3.14+ behavior where get_event_loop() raises RuntimeError
+        # when there's no current event loop in the main thread.
+        try:
+            loop = asyncio.get_event_loop()
+        except RuntimeError:
+            # No running event loop, create and set a new one
+            loop = asyncio.new_event_loop()
+            asyncio.set_event_loop(loop)
 
         if stop_signals is DEFAULT_NONE and platform.system() != "Windows":
             stop_signals = (signal.SIGINT, signal.SIGTERM, signal.SIGABRT)
@@ -1302,8 +1307,7 @@ class Application(
                             coroutine,
                             update=update,
                             name=(
-                                f"Application:{self.bot.id}:process_update_non_blocking"
-                                f":{handler}"
+                                f"Application:{self.bot.id}:process_update_non_blocking:{handler}"
                             ),
                         )
                     else:
